import { presetCommon } from "./common.js";
import { presetEverything } from "./everything.js";
import { presetMinimal } from "./minimal.js";
import * as bingo_stratum757 from "bingo-stratum";
import * as zod628 from "zod";

//#region src/presets/index.d.ts
declare const presets: {
  common: bingo_stratum757.Preset<{
    access: zod628.ZodUnion<[zod628.ZodLiteral<"public">, zod628.ZodLiteral<"restricted">]>;
    author: zod628.ZodOptional<zod628.ZodString>;
    bin: zod628.ZodOptional<zod628.ZodUnion<[zod628.ZodString, zod628.ZodRecord<zod628.ZodString, zod628.ZodString>]>>;
    contributors: zod628.ZodOptional<zod628.ZodArray<zod628.ZodObject<{
      avatar_url: zod628.ZodString;
      contributions: zod628.ZodArray<zod628.ZodString, "many">;
      login: zod628.ZodString;
      name: zod628.ZodString;
      profile: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod628.ZodDefault<zod628.ZodString>;
    directory: zod628.ZodString;
    documentation: zod628.ZodObject<{
      development: zod628.ZodOptional<zod628.ZodString>;
      readme: zod628.ZodObject<{
        additional: zod628.ZodOptional<zod628.ZodString>;
        explainer: zod628.ZodOptional<zod628.ZodString>;
        footnotes: zod628.ZodOptional<zod628.ZodString>;
        usage: zod628.ZodOptional<zod628.ZodString>;
      }, "strip", zod628.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod628.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod628.ZodEffects<zod628.ZodUnion<[zod628.ZodString, zod628.ZodObject<{
      github: zod628.ZodString;
      npm: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod628.ZodOptional<zod628.ZodString>;
    existingLabels: zod628.ZodOptional<zod628.ZodArray<zod628.ZodObject<{
      color: zod628.ZodString;
      description: zod628.ZodString;
      name: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod628.ZodOptional<zod628.ZodString>;
    guide: zod628.ZodOptional<zod628.ZodObject<{
      href: zod628.ZodString;
      title: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod628.ZodOptional<zod628.ZodArray<zod628.ZodString, "many">>;
    logo: zod628.ZodOptional<zod628.ZodObject<{
      alt: zod628.ZodString;
      height: zod628.ZodOptional<zod628.ZodNumber>;
      src: zod628.ZodString;
      width: zod628.ZodOptional<zod628.ZodNumber>;
    }, "strip", zod628.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod628.ZodObject<{
      minimum: zod628.ZodString;
      pinned: zod628.ZodOptional<zod628.ZodString>;
    }, "strip", zod628.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod628.ZodString;
    packageData: zod628.ZodOptional<zod628.ZodObject<{
      dependencies: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodString>>;
      devDependencies: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodString>>;
      peerDependencies: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodString>>;
      peerDependenciesMeta: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodUnknown>>;
      scripts: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodOptional<zod628.ZodString>>>;
    }, "strip", zod628.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod628.ZodOptional<zod628.ZodString>;
    repository: zod628.ZodString;
    rulesetId: zod628.ZodOptional<zod628.ZodString>;
    title: zod628.ZodString;
    type: zod628.ZodOptional<zod628.ZodUnion<[zod628.ZodLiteral<"commonjs">, zod628.ZodLiteral<"module">]>>;
    version: zod628.ZodOptional<zod628.ZodString>;
    words: zod628.ZodOptional<zod628.ZodArray<zod628.ZodString, "many">>;
    workflowsVersions: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodRecord<zod628.ZodString, zod628.ZodObject<{
      hash: zod628.ZodOptional<zod628.ZodString>;
      pinned: zod628.ZodOptional<zod628.ZodBoolean>;
    }, "strip", zod628.ZodTypeAny, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }>>>>;
  }>;
  everything: bingo_stratum757.Preset<{
    access: zod628.ZodUnion<[zod628.ZodLiteral<"public">, zod628.ZodLiteral<"restricted">]>;
    author: zod628.ZodOptional<zod628.ZodString>;
    bin: zod628.ZodOptional<zod628.ZodUnion<[zod628.ZodString, zod628.ZodRecord<zod628.ZodString, zod628.ZodString>]>>;
    contributors: zod628.ZodOptional<zod628.ZodArray<zod628.ZodObject<{
      avatar_url: zod628.ZodString;
      contributions: zod628.ZodArray<zod628.ZodString, "many">;
      login: zod628.ZodString;
      name: zod628.ZodString;
      profile: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod628.ZodDefault<zod628.ZodString>;
    directory: zod628.ZodString;
    documentation: zod628.ZodObject<{
      development: zod628.ZodOptional<zod628.ZodString>;
      readme: zod628.ZodObject<{
        additional: zod628.ZodOptional<zod628.ZodString>;
        explainer: zod628.ZodOptional<zod628.ZodString>;
        footnotes: zod628.ZodOptional<zod628.ZodString>;
        usage: zod628.ZodOptional<zod628.ZodString>;
      }, "strip", zod628.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod628.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod628.ZodEffects<zod628.ZodUnion<[zod628.ZodString, zod628.ZodObject<{
      github: zod628.ZodString;
      npm: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod628.ZodOptional<zod628.ZodString>;
    existingLabels: zod628.ZodOptional<zod628.ZodArray<zod628.ZodObject<{
      color: zod628.ZodString;
      description: zod628.ZodString;
      name: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod628.ZodOptional<zod628.ZodString>;
    guide: zod628.ZodOptional<zod628.ZodObject<{
      href: zod628.ZodString;
      title: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod628.ZodOptional<zod628.ZodArray<zod628.ZodString, "many">>;
    logo: zod628.ZodOptional<zod628.ZodObject<{
      alt: zod628.ZodString;
      height: zod628.ZodOptional<zod628.ZodNumber>;
      src: zod628.ZodString;
      width: zod628.ZodOptional<zod628.ZodNumber>;
    }, "strip", zod628.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod628.ZodObject<{
      minimum: zod628.ZodString;
      pinned: zod628.ZodOptional<zod628.ZodString>;
    }, "strip", zod628.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod628.ZodString;
    packageData: zod628.ZodOptional<zod628.ZodObject<{
      dependencies: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodString>>;
      devDependencies: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodString>>;
      peerDependencies: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodString>>;
      peerDependenciesMeta: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodUnknown>>;
      scripts: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodOptional<zod628.ZodString>>>;
    }, "strip", zod628.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod628.ZodOptional<zod628.ZodString>;
    repository: zod628.ZodString;
    rulesetId: zod628.ZodOptional<zod628.ZodString>;
    title: zod628.ZodString;
    type: zod628.ZodOptional<zod628.ZodUnion<[zod628.ZodLiteral<"commonjs">, zod628.ZodLiteral<"module">]>>;
    version: zod628.ZodOptional<zod628.ZodString>;
    words: zod628.ZodOptional<zod628.ZodArray<zod628.ZodString, "many">>;
    workflowsVersions: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodRecord<zod628.ZodString, zod628.ZodObject<{
      hash: zod628.ZodOptional<zod628.ZodString>;
      pinned: zod628.ZodOptional<zod628.ZodBoolean>;
    }, "strip", zod628.ZodTypeAny, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }>>>>;
  }>;
  minimal: bingo_stratum757.Preset<{
    access: zod628.ZodUnion<[zod628.ZodLiteral<"public">, zod628.ZodLiteral<"restricted">]>;
    author: zod628.ZodOptional<zod628.ZodString>;
    bin: zod628.ZodOptional<zod628.ZodUnion<[zod628.ZodString, zod628.ZodRecord<zod628.ZodString, zod628.ZodString>]>>;
    contributors: zod628.ZodOptional<zod628.ZodArray<zod628.ZodObject<{
      avatar_url: zod628.ZodString;
      contributions: zod628.ZodArray<zod628.ZodString, "many">;
      login: zod628.ZodString;
      name: zod628.ZodString;
      profile: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }, {
      avatar_url: string;
      contributions: string[];
      login: string;
      name: string;
      profile: string;
    }>, "many">>;
    description: zod628.ZodDefault<zod628.ZodString>;
    directory: zod628.ZodString;
    documentation: zod628.ZodObject<{
      development: zod628.ZodOptional<zod628.ZodString>;
      readme: zod628.ZodObject<{
        additional: zod628.ZodOptional<zod628.ZodString>;
        explainer: zod628.ZodOptional<zod628.ZodString>;
        footnotes: zod628.ZodOptional<zod628.ZodString>;
        usage: zod628.ZodOptional<zod628.ZodString>;
      }, "strip", zod628.ZodTypeAny, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }, {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      }>;
    }, "strip", zod628.ZodTypeAny, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }, {
      readme: {
        additional?: string | undefined;
        explainer?: string | undefined;
        footnotes?: string | undefined;
        usage?: string | undefined;
      };
      development?: string | undefined;
    }>;
    email: zod628.ZodEffects<zod628.ZodUnion<[zod628.ZodString, zod628.ZodObject<{
      github: zod628.ZodString;
      npm: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      github: string;
      npm: string;
    }, {
      github: string;
      npm: string;
    }>]>, {
      github: string;
      npm: string;
    }, string | {
      github: string;
      npm: string;
    }>;
    emoji: zod628.ZodOptional<zod628.ZodString>;
    existingLabels: zod628.ZodOptional<zod628.ZodArray<zod628.ZodObject<{
      color: zod628.ZodString;
      description: zod628.ZodString;
      name: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      name: string;
      description: string;
      color: string;
    }, {
      name: string;
      description: string;
      color: string;
    }>, "many">>;
    funding: zod628.ZodOptional<zod628.ZodString>;
    guide: zod628.ZodOptional<zod628.ZodObject<{
      href: zod628.ZodString;
      title: zod628.ZodString;
    }, "strip", zod628.ZodTypeAny, {
      href: string;
      title: string;
    }, {
      href: string;
      title: string;
    }>>;
    keywords: zod628.ZodOptional<zod628.ZodArray<zod628.ZodString, "many">>;
    logo: zod628.ZodOptional<zod628.ZodObject<{
      alt: zod628.ZodString;
      height: zod628.ZodOptional<zod628.ZodNumber>;
      src: zod628.ZodString;
      width: zod628.ZodOptional<zod628.ZodNumber>;
    }, "strip", zod628.ZodTypeAny, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }, {
      alt: string;
      src: string;
      height?: number | undefined;
      width?: number | undefined;
    }>>;
    node: zod628.ZodObject<{
      minimum: zod628.ZodString;
      pinned: zod628.ZodOptional<zod628.ZodString>;
    }, "strip", zod628.ZodTypeAny, {
      minimum: string;
      pinned?: string | undefined;
    }, {
      minimum: string;
      pinned?: string | undefined;
    }>;
    owner: zod628.ZodString;
    packageData: zod628.ZodOptional<zod628.ZodObject<{
      dependencies: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodString>>;
      devDependencies: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodString>>;
      peerDependencies: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodString>>;
      peerDependenciesMeta: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodUnknown>>;
      scripts: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodOptional<zod628.ZodString>>>;
    }, "strip", zod628.ZodTypeAny, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }, {
      dependencies?: Record<string, string> | undefined;
      devDependencies?: Record<string, string> | undefined;
      peerDependencies?: Record<string, string> | undefined;
      peerDependenciesMeta?: Record<string, unknown> | undefined;
      scripts?: Record<string, string | undefined> | undefined;
    }>>;
    pnpm: zod628.ZodOptional<zod628.ZodString>;
    repository: zod628.ZodString;
    rulesetId: zod628.ZodOptional<zod628.ZodString>;
    title: zod628.ZodString;
    type: zod628.ZodOptional<zod628.ZodUnion<[zod628.ZodLiteral<"commonjs">, zod628.ZodLiteral<"module">]>>;
    version: zod628.ZodOptional<zod628.ZodString>;
    words: zod628.ZodOptional<zod628.ZodArray<zod628.ZodString, "many">>;
    workflowsVersions: zod628.ZodOptional<zod628.ZodRecord<zod628.ZodString, zod628.ZodRecord<zod628.ZodString, zod628.ZodObject<{
      hash: zod628.ZodOptional<zod628.ZodString>;
      pinned: zod628.ZodOptional<zod628.ZodBoolean>;
    }, "strip", zod628.ZodTypeAny, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }, {
      pinned?: boolean | undefined;
      hash?: string | undefined;
    }>>>>;
  }>;
};
//#endregion
export { presetCommon, presetEverything, presetMinimal, presets };
//# sourceMappingURL=index.d.ts.map